MCPcopy Create free account
hub / github.com/ROCm/rocPRIM / thread_reduce_kernel

Function thread_reduce_kernel

test/rocprim/test_thread_algos.cpp:292–298  ·  view source on GitHub ↗

Source from the content-addressed store, hash-verified

290
291template<class Type, int32_t Length>
292__global__
293void thread_reduce_kernel(Type* const device_input, Type* device_output)
294{
295 size_t index = (blockIdx.x * blockDim.x + threadIdx.x) * Length;
296
297 device_output[index] = rocprim::thread_reduce<Length>(&device_input[index], sum_op());
298}
299
300template<class Type, int32_t Length>
301__global__

Callers

nothing calls this directly

Calls 1

sum_opClass · 0.85

Tested by

no test coverage detected